#
# Conditional build:
%bcond_with	dietlibc	# static dietlibc library
%bcond_with	libcap		# Linux capabilities usage
%bcond_without	static_libs	# static library
#
Summary:	Cryptographic library based on the code from GnuPG
Summary(es.UTF-8):	Libgcrypt es una biblioteca general de desarrole embasada em GnuPG
Summary(pl.UTF-8):	Biblioteka kryptograficzna oparta na kodzie GnuPG
Summary(pt_BR.UTF-8):	libgcrypt é uma biblioteca de criptografia de uso geral baseada no GnuPG
Name:		libgcrypt
Version:	1.11.1
Release:	1
License:	LGPL v2.1+
Group:		Libraries
Source0:	https://www.gnupg.org/ftp/gcrypt/libgcrypt/%{name}-%{version}.tar.bz2
# Source0-md5:	66bf74fd479dbba81e9283b669ad4233
Patch0:		%{name}-info.patch
Patch1:		%{name}-libgcrypt_config.patch
URL:		https://directory.fsf.org/wiki/Libgcrypt
BuildRequires:	autoconf >= 2.69
BuildRequires:	automake >= 1:1.14
BuildRequires:	binutils >= 2:2.12
%{?with_dietlibc:BuildRequires:	dietlibc-static >= 2:0.31-5}
BuildRequires:	gcc >= 5:3.2
%{?with_libcap:BuildRequires:	libcap-devel}
BuildRequires:	libgpg-error-devel >= 1.49
BuildRequires:	libtool >= 2:2.2.6
BuildRequires:	texinfo
Requires:	libgpg-error >= 1.49
# getrandom() for getentropy()
Requires:	uname(release) >= 3.17
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# for some reason known only to rpm there must be "\\|" not "\|" here
%define		dietarch	%(echo %{_target_cpu} | sed -e 's/i.86\\|pentium.\\|athlon/i386/;s/amd64/x86_64/;s/armv.*/arm/')
%define		dietlibdir	%{_prefix}/lib/dietlibc/lib-%{dietarch}

%description
This is a general purpose cryptographic library based on the code from
GnuPG. It provides functions for all cryptograhic building blocks:
symmetric ciphers (AES, DES, Blowfish, CAST5, Twofish, Arcfour), hash
algorithms (MD5, RIPE-MD160, SHA-1, TIGER-192), MACs (HMAC for all
hash algorithms), public key algorithms (RSA, ElGamal, DSA), large
integer functions, random numbers and a lot of supporting functions.

%description -l pl.UTF-8
Ten pakiet zawiera bibliotekę kryptograficzną ogólnego przeznaczenia,
opartą na kodzie GnuPG. Biblioteka ta dostarcza funkcje do wszystkich
podstawowych bloków kryptografii: szyfrów symetrycznych (AES, DES,
Blowfish, CAST5, Twofish, Acrfour), algorytmów mieszających (MD5,
RIPE-MD160, SHA-1, RIGER-192), MAC-ów (HMAC dla wszystkich algorytmów
mieszających), algorytmów klucza publicznego (RSA, ElGamal, DSA),
funkcji dużych liczb całkowitych, liczb losowych i wiele funkcji
pomocniczych.

%description -l pt_BR.UTF-8
Libgcrypt é uma biblioteca de criptografia de uso geral baseada no
GnuPG.

%package tools
Summary:	Additional binary tools for libgcrypt
Summary(pl.UTF-8):	Dodatkowe narzędzia dla biblioteki libgcrypt
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description tools
Additional binary tools for libgcrypt.

%description tools -l pl.UTF-8
Dodatkowe narzędzia dla biblioteki libgcrypt.

%package devel
Summary:	Header files etc to develop libgcrypt applications
Summary(es.UTF-8):	Archivos de desarrollo de libgcrypt
Summary(pl.UTF-8):	Pliki nagłówkowe i inne do libgcrypt
Summary(pt_BR.UTF-8):	Arquivos de desenvolvimento da libgcrypt
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
%{?with_libcap:Requires:	libcap-devel}
Requires:	libgpg-error-devel >= 1.49

%description devel
Header files etc to develop libgcrypt applications.

%description devel -l pl.UTF-8
Pliki nagłówkowe i inne do libgcrypt.

%description devel -l pt_BR.UTF-8
Bibliotecas de desenvolvimento para libgcrypt.

%package static
Summary:	Static libgcrypt library
Summary(es.UTF-8):	Archivos de desarrollo de libgcrypt - estatico
Summary(pl.UTF-8):	Biblioteka statyczna libgcrypt
Summary(pt_BR.UTF-8):	Arquivos de desenvolvimento da libgcrypt - biblioteca estática
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libgcrypt library.

%description static -l pl.UTF-8
Biblioteka statyczna libgcrypt.

%description static -l pt_BR.UTF-8
Bibliotecas de desenvolvimento para libgcrypt - estático.

%package dietlibc
Summary:	Static dietlibc libgcrypt library
Summary(pl.UTF-8):	Biblioteka statyczna dietlibc libgcrypt
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description dietlibc
Static dietlibc libgcrypt library.

%description dietlibc -l pl.UTF-8
Biblioteka statyczna dietlibc libgcrypt.

%prep
%setup -q
%patch -P0 -p1
%patch -P1 -p1

%build
%{__rm} m4/libtool.m4
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__automake}

%if %{with dietlibc}
%configure \
	CC="diet %{__cc} %{rpmcflags} %{rpmldflags} -Os" \
	--enable-static \
	--disable-shared

# libtool sucks, build just the libs
%{__make} -C compat
%{__make} -C cipher
%{__make} -C mpi
%{__make} -C random
%{__make} -C src \
	PROGRAMS=
%{__mv} src/.libs/libgcrypt.a diet-libgcrypt.a
%{__make} clean
%endif

%configure \
	%{?with_static_libs:--enable-static} \
	%{?with_libcap:--with-capabilities}

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{?with_dietlibc:install -d $RPM_BUILD_ROOT%{dietlibdir}}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	m4datadir=%{_aclocaldir}

install -d $RPM_BUILD_ROOT/%{_lib}
%{__mv} $RPM_BUILD_ROOT%{_libdir}/libgcrypt.so.* $RPM_BUILD_ROOT/%{_lib}
ln -sf /%{_lib}/$(basename $RPM_BUILD_ROOT/%{_lib}/libgcrypt.so.*.*.*) \
	$RPM_BUILD_ROOT%{_libdir}/libgcrypt.so

%{?with_dietlibc:install diet-libgcrypt.a $RPM_BUILD_ROOT%{dietlibdir}/libgcrypt.a}

%clean
rm -rf $RPM_BUILD_ROOT

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post	devel -p /sbin/postshell
-/usr/sbin/fix-info-dir -c %{_infodir}

%postun	devel -p /sbin/postshell
-/usr/sbin/fix-info-dir -c %{_infodir}

%files
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%attr(755,root,root) /%{_lib}/libgcrypt.so.*.*.*
%attr(755,root,root) %ghost /%{_lib}/libgcrypt.so.20

%files tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/dumpsexp
%attr(755,root,root) %{_bindir}/hmac256
%attr(755,root,root) %{_bindir}/mpicalc
%{_mandir}/man1/hmac256.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libgcrypt.so
%{_libdir}/libgcrypt.la
%{_includedir}/gcrypt*.h
%{_pkgconfigdir}/libgcrypt.pc
%{_aclocaldir}/libgcrypt.m4
%{_infodir}/gcrypt.info*

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libgcrypt.a
%endif

%if %{with dietlibc}
%files dietlibc
%defattr(644,root,root,755)
%{dietlibdir}/libgcrypt.a
%endif
%changelog
* Sun May 11 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libgcrypt.git;a=log;h=master

* Thu May 08 2025 Jan Palus <atler@pld-linux.org> d6325f0
- up to 1.11.1

* Thu May 08 2025 Jan Palus <atler@pld-linux.org> 85b07e9
- use %patch -P

* Tue Aug 27 2024 Jakub Bogusz <qboosh@pld-linux.org> db91d61
- updated Source0 URL

* Sun Jun 23 2024 Jakub Bogusz <qboosh@pld-linux.org> 89c1b08
- updated to 1.11.0

* Tue Nov 14 2023 Jan Palus <atler@pld-linux.org> 413d8ff
- add static_libs bcond

* Tue Nov 14 2023 Jan Palus <atler@pld-linux.org> 2093c7d
- up to 1.10.3

* Fri Apr 07 2023 Jan Palus <atler@pld-linux.org> 6283abb
- up to 1.10.2

* Thu Jan 19 2023 Jan Palus <atler@pld-linux.org> 8eb18f1
- replace fgrep with grep -F lin libgcrypt-config; rel 2

* Fri Apr 01 2022 Jakub Bogusz <qboosh@pld-linux.org> 9885abc
- updated to 1.10.1
- removed outdated poll patch
- require Linux >= 3.17 for getentropy() based random source

* Sun Aug 22 2021 Jan Palus <atler@pld-linux.org> c88d63e
- up to 1.9.4

* Tue Apr 20 2021 Jan Palus <atler@pld-linux.org> 2e87552
- up to 1.9.3

* Wed Feb 17 2021 Jan Palus <atler@pld-linux.org> 4bb1b8a
- up to 1.9.2

* Fri Jan 29 2021 Jan Palus <atler@pld-linux.org> d766691
- up to 1.9.1 (critical security fix)

* Fri Jan 22 2021 Jan Palus <atler@pld-linux.org> 1f0aeb1
- upstream patch to fix build on arm

* Wed Jan 20 2021 Jan Palus <atler@pld-linux.org> 099faaf
- up to 1.9.0

* Sat Oct 24 2020 Jakub Bogusz <qboosh@pld-linux.org> 27a2113
- updated to 1.8.7

* Mon Jul 06 2020 Jakub Bogusz <qboosh@pld-linux.org> 8b3e8dd
- updated to 1.8.6

* Sun Sep 01 2019 Jakub Bogusz <qboosh@pld-linux.org> a890b62
- updated to 1.8.5 (adds CVE-2019-13627 mitigation, contains .pc file at last)

* Sat Oct 27 2018 Adam Gołębiowski <adamg@pld-linux.org> 4d0ca8e
- updated to 1.8.4

* Wed Jun 20 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> b05701c
- up to 1.8.3

